@@ -1,6 +1,6 @@
 package DBIx::Class::AuditLog;
 {
-  $DBIx::Class::AuditLog::VERSION = '0.2.6';
+  $DBIx::Class::AuditLog::VERSION = '0.3.0';
 }
 
 use base qw/DBIx::Class/;
@@ -8,7 +8,6 @@ use base qw/DBIx::Class/;
 use strict;
 use warnings;
 
-
 sub insert {
     my $self = shift;
 
@@ -26,25 +25,33 @@ sub insert {
     return $result;
 }
 
-
 sub update {
     my $self = shift;
-
     my $stored_row = $self->get_from_storage;
     my %old_data   = $stored_row->get_columns;
-    my %new_data   = $self->get_dirty_columns;
+    my %new_data   = $self->get_columns;
     my @changed_columns = keys %{$_[0]||{}};
 
     my $result = $self->next::method(@_);
 
-    # find list of passed in update values when $row->update({...}) is used
-    if ( @changed_columns ) {
-        @new_data{ @changed_columns } = map $self->get_column($_), @changed_columns;
+    if (@changed_columns) {
+        @new_data{@changed_columns} = map $self->get_column($_),
+            @changed_columns;
+    }
+
+    foreach my $col ($self->columns){
+	    if($self->_force_audit($col)){
+		    $old_data{$col} = $stored_row->get_column($col) 
+		    	unless defined $old_data{$col};
+		    $new_data{$col} = $self->get_column($col) 
+		    	unless defined $new_data{$col};
+	    }
     }
 
     foreach my $key ( keys %new_data ) {
         if (   defined $old_data{$key}
             && defined $new_data{$key}
+	    && (! $self->_force_audit($key))
             && $old_data{$key} eq $new_data{$key} )
         {
             delete $new_data{$key};
@@ -63,7 +70,6 @@ sub update {
     return $result;
 }
 
-
 sub delete {
     my $self = shift;
 
@@ -87,7 +93,6 @@ sub _audit_log_schema {
     return $self->result_source->schema->audit_log_schema;
 }
 
-
 sub _action_setup {
     my $self = shift;
     my $row  = shift;
@@ -102,7 +107,6 @@ sub _action_setup {
 
 }
 
-
 sub _store_changes {
     my $self       = shift;
     my $action     = shift;
@@ -117,33 +121,88 @@ sub _store_changes {
             my $field
                 = $table->find_or_create_related( 'Field', { name => $column } );
 
+        my $create_params = {
+            field => $field->id,
+        };
+
+        if($self->_do_modify_audit_value($column)){
+                    $create_params->{new_value} = 
+                $self->_modify_audit_value($column,$new_values->{$column});
+                    $create_params->{old_value} = 
+                $self->_modify_audit_value($column,$old_values->{$column});
+        }else{
+                    $create_params->{new_value} = $new_values->{$column};
+                    $create_params->{old_value} = $old_values->{$column};
+        }
+
             $action->create_related(
                 'Change',
-                {   field     => $field->id,
-                    new_value => $new_values->{$column},
-                    old_value => $old_values->{$column},
-                }
+		$create_params,
             );
         }
     }
 }
 
+sub _force_audit{
+    my ($self, $column) = @_;
+
+    my $info = $self->column_info($column);
+    return
+        defined $info->{force_audit_log_column};
+
+}
 
 sub _do_audit {
     my $self   = shift;
     my $column = shift;
 
+    return 1 if $self->_force_audit($column);
+
     my $info = $self->column_info($column);
     return
         defined $info->{audit_log_column}
         && $info->{audit_log_column} == 0 ? 0 : 1;
 }
 
+sub _do_modify_audit_value{
+    my $self   = shift;
+    my $column = shift;
+
+    my $info = $self->column_info($column);
+
+    return
+        $info->{modify_audit_value} ? 1 : 0; 
+}
+
+sub _modify_audit_value{
+    my $self   = shift;
+    my $column = shift;
+    my $value = shift;
+
+    my $info = $self->column_info($column);
+    my $meth = $info->{modify_audit_value};
+    return $value unless 
+        defined $meth;
+
+    return &$meth($self, $value)
+        if ref($meth) eq 'CODE';
+
+    $meth = "modify_audit_$column"
+        unless $self->can($meth);
+
+    return $self->$meth($value)
+        if $self->can($meth);
+
+    die "unable to find modify_audit_method ($meth) for $column in $self";
+
+}
+
 # ABSTRACT: Simple activity audit logging for DBIx::Class
 
 1;
 
-__END__
+
+
 =pod
 
 =head1 NAME
@@ -152,6 +211,14 @@ DBIx::Class::AuditLog - Simple activity audit logging for DBIx::Class
 
 =head1 VERSION
 
+version 0.3.0
+
+=head1 NAME
+
+DBIx::Class::AuditLog - Simple activity audit logging for DBIx::Class
+
+=head1 VERSION
+
 version 0.2.6
 
 =head1 DBIx::Class OVERRIDDEN METHODS
@@ -195,6 +262,46 @@ Returns 1 or 0 if the column should be audited or not.
 Requires:
     column: the name of the column/field to check
 
+=head2 _force_audit
+
+Returns 1 or 0 if the column should be audited even if its value did not change.
+
+Requires:
+    column: the name of the column/field to check
+
+=head2 _do_modify_audit_value
+
+Returns 1 or 0 if the columns value should be modified before audit.
+
+Requires:
+    column: the name of the column/field to check
+
+=head2 _modify_audit_value
+
+Modifies the colums audit-value. Dies if no modify-method could be found.
+
+Returns:
+    the modified value
+
+Requires:
+    column: the name of the column/field to check
+    value: the original value
+
+=head1 AUTHOR
+
+Mark Jubenville <ioncache@gmail.com>
+
+=head1 CONTRIBUTORS
+
+Lukas Thiemeier <lukast@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Mark Jubenville.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 AUTHOR
 
 Mark Jubenville <ioncache@gmail.com>
@@ -208,3 +315,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
